commands

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Execute adds all child commands to the root command and sets flags appropriately.

func RegisterSeeder

func RegisterSeeder(name string, fn SeederFunc)

RegisterSeeder registers a named seeder function. Call this from your main package before invoking commands.Execute().

Types

type SeederFunc

type SeederFunc func(ctx context.Context, client *quark.Client) error

SeederFunc is the signature for a registered seeder function.

Jump to