Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute() error
Execute adds all child commands to the root command and sets flags appropriately.
func RegisterSeeder ¶
func RegisterSeeder(name string, fn SeederFunc)
RegisterSeeder registers a named seeder function. Call this from your main package before invoking commands.Execute().
Types ¶
Click to show internal directories.
Click to hide internal directories.